@@ -24,12 +24,9 @@ test_that("recursive printing of subfields", {
   z2 <- bq_field("z2", "record", fields = list(z1))
   z3 <- bq_field("z3", "record", fields = list(z2))
 
-  expect_known_output({
-    cat_line("Field:")
+  expect_snapshot({
     print(z3)
 
-    cat_line()
-    cat_line("Fields: ")
     print(z3$fields)
-  }, "bq-field-print.txt")
+  })
 })
